==> jaysonic-1.3.3.tgz: package/lib/buffer.js <==
"use strict";

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

var MessageBuffer =
/*#__PURE__*/
function () {
  function MessageBuffer(delimiter) {
    _classCallCheck(this, MessageBuffer);

    this.delimiter = delimiter;
    this.buffer = "";
  }

  _createClass(MessageBuffer, [{
    key: "isFinished",
    value: function isFinished() {
      if (this.buffer.length === 0 || this.buffer.indexOf(this.delimiter) === -1) {
        return true;
      }

      return false;
    }
  }, {
    key: "push",
    value: function push(data) {
      this.buffer += data;
    }
  }, {
    key: "getMessage",
    value: function getMessage() {
      var delimiterIndex = this.buffer.indexOf(this.delimiter);

      if (delimiterIndex !== -1) {
        var message = this.buffer.slice(0, delimiterIndex);
        this.buffer = this.buffer.replace(message + this.delimiter, "");
        return message;
      }

      return null;
    }
  }, {
    key: "handleData",
    value: function handleData() {
      /**
       * Try to accumulate the buffer with messages
       *
       * If the server isnt sending delimiters for some reason
       * then nothing will ever come back for these requests
       */
      var message = this.getMessage();
      return message;
    }
  }]);

  return MessageBuffer;
}();

module.exports = {
  MessageBuffer: MessageBuffer
};

==> jaysonic-2.0.1.tgz: package/lib/buffer.js <==
"use strict";

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

var MessageBuffer =
/*#__PURE__*/
function () {
  /**
   * we can receive whole messages, or parital so we need to buffer
   *
   * whole message: {"jsonrpc": 2.0, "params": ["hello"], id: 1}\n
   *
   * partial message: {"jsonrpc": 2.0, "params"
   */
  function MessageBuffer(delimiter) {
    _classCallCheck(this, MessageBuffer);

    this.delimiter = delimiter;
    this.buffer = "";
  }

  _createClass(MessageBuffer, [{
    key: "isFinished",
    value: function isFinished() {
      if (this.buffer.length === 0 || this.buffer.indexOf(this.delimiter) === -1) {
        return true;
      }

      return false;
    }
  }, {
    key: "push",
    value: function push(data) {
      this.buffer += data;
    }
  }, {
    key: "getMessage",
    value: function getMessage() {
      var delimiterIndex = this.buffer.indexOf(this.delimiter);

      if (delimiterIndex !== -1) {
        var message = this.buffer.slice(0, delimiterIndex);
        this.buffer = this.buffer.replace(message + this.delimiter, "");
        return message;
      }

      return null;
    }
  }, {
    key: "handleData",
    value: function handleData() {
      /**
       * Try to accumulate the buffer with messages
       *
       * If the server isnt sending delimiters for some reason
       * then nothing will ever come back for these requests
       */
      return this.getMessage();
    }
  }]);

  return MessageBuffer;
}();

module.exports = {
  MessageBuffer: MessageBuffer
};
